from kplot.lib import *

kplot.lib.loadtheme("colorblind")
